@@ -11,16 +11,17 @@ use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\Persistence\Mapping\ClassMetadata as PersistenceClassMetadata;
 use Doctrine\Persistence\Mapping\Driver\FileDriver;
+use Doctrine\Persistence\Mapping\Driver\FileLocator;
 use DOMDocument;
 use InvalidArgumentException;
 use LogicException;
 use SimpleXMLElement;
 
 use function assert;
-use function class_exists;
 use function constant;
 use function count;
 use function defined;
+use function enum_exists;
 use function explode;
 use function extension_loaded;
 use function file_get_contents;
@@ -37,49 +38,50 @@ use function strtoupper;
  * XmlDriver is a metadata driver that enables mapping through XML files.
  *
  * @link        www.doctrine-project.org
+ *
+ * @template-extends FileDriver<SimpleXMLElement>
  */
 class XmlDriver extends FileDriver
 {
-    public const DEFAULT_FILE_EXTENSION = '.dcm.xml';
+    use LoadMappingFileImplementation;
 
-    /** @var bool */
-    private $isXsdValidationEnabled;
+    public const DEFAULT_FILE_EXTENSION = '.dcm.xml';
 
     /**
      * {@inheritDoc}
      */
-    public function __construct($locator, $fileExtension = self::DEFAULT_FILE_EXTENSION, bool $isXsdValidationEnabled = false)
-    {
+    public function __construct(
+        string|array|FileLocator $locator,
+        string $fileExtension = self::DEFAULT_FILE_EXTENSION,
+        private readonly bool $isXsdValidationEnabled = true,
+    ) {
         if (! extension_loaded('simplexml')) {
             throw new LogicException(
                 'The XML metadata driver cannot be enabled because the SimpleXML PHP extension is missing.'
-                . ' Please configure PHP with SimpleXML or choose a different metadata driver.'
+                . ' Please configure PHP with SimpleXML or choose a different metadata driver.',
             );
         }
 
         if ($isXsdValidationEnabled && ! extension_loaded('dom')) {
             throw new LogicException(
-                'XSD validation cannot be enabled because the DOM extension is missing.'
+                'XSD validation cannot be enabled because the DOM extension is missing.',
             );
         }
 
-        $this->isXsdValidationEnabled = $isXsdValidationEnabled;
-
         parent::__construct($locator, $fileExtension);
     }
 
     /**
      * {@inheritDoc}
      *
-     * @psalm-param class-string<T> $className
-     * @psalm-param ClassMetadata<T> $metadata
+     * @param class-string<T>  $className
+     * @param ClassMetadata<T> $metadata
      *
      * @template T of object
      */
-    public function loadMetadataForClass($className, PersistenceClassMetadata $metadata)
+    public function loadMetadataForClass($className, PersistenceClassMetadata $metadata): void
     {
         $xmlRoot = $this->getElement($className);
-        assert($xmlRoot instanceof SimpleXMLElement);
 
         if ($xmlRoot->getName() === 'entity') {
             if (isset($xmlRoot['repository-class'])) {
@@ -91,7 +93,7 @@ class XmlDriver extends FileDriver
             }
         } elseif ($xmlRoot->getName() === 'mapped-superclass') {
             $metadata->setCustomRepositoryClass(
-                isset($xmlRoot['repository-class']) ? (string) $xmlRoot['repository-class'] : null
+                isset($xmlRoot['repository-class']) ? (string) $xmlRoot['repository-class'] : null,
             );
             $metadata->isMappedSuperclass = true;
         } elseif ($xmlRoot->getName() === 'embeddable') {
@@ -118,74 +120,6 @@ class XmlDriver extends FileDriver
             $metadata->enableCache($this->cacheToArray($xmlRoot->cache));
         }
 
-        // Evaluate named queries
-        if (isset($xmlRoot->{'named-queries'})) {
-            foreach ($xmlRoot->{'named-queries'}->{'named-query'} ?? [] as $namedQueryElement) {
-                $metadata->addNamedQuery(
-                    [
-                        'name'  => (string) $namedQueryElement['name'],
-                        'query' => (string) $namedQueryElement['query'],
-                    ]
-                );
-            }
-        }
-
-        // Evaluate native named queries
-        if (isset($xmlRoot->{'named-native-queries'})) {
-            foreach ($xmlRoot->{'named-native-queries'}->{'named-native-query'} ?? [] as $nativeQueryElement) {
-                $metadata->addNamedNativeQuery(
-                    [
-                        'name'              => isset($nativeQueryElement['name']) ? (string) $nativeQueryElement['name'] : null,
-                        'query'             => isset($nativeQueryElement->query) ? (string) $nativeQueryElement->query : null,
-                        'resultClass'       => isset($nativeQueryElement['result-class']) ? (string) $nativeQueryElement['result-class'] : null,
-                        'resultSetMapping'  => isset($nativeQueryElement['result-set-mapping']) ? (string) $nativeQueryElement['result-set-mapping'] : null,
-                    ]
-                );
-            }
-        }
-
-        // Evaluate sql result set mapping
-        if (isset($xmlRoot->{'sql-result-set-mappings'})) {
-            foreach ($xmlRoot->{'sql-result-set-mappings'}->{'sql-result-set-mapping'} ?? [] as $rsmElement) {
-                $entities = [];
-                $columns  = [];
-                foreach ($rsmElement as $entityElement) {
-                    //<entity-result/>
-                    if (isset($entityElement['entity-class'])) {
-                        $entityResult = [
-                            'fields'                => [],
-                            'entityClass'           => (string) $entityElement['entity-class'],
-                            'discriminatorColumn'   => isset($entityElement['discriminator-column']) ? (string) $entityElement['discriminator-column'] : null,
-                        ];
-
-                        foreach ($entityElement as $fieldElement) {
-                            $entityResult['fields'][] = [
-                                'name'      => isset($fieldElement['name']) ? (string) $fieldElement['name'] : null,
-                                'column'    => isset($fieldElement['column']) ? (string) $fieldElement['column'] : null,
-                            ];
-                        }
-
-                        $entities[] = $entityResult;
-                    }
-
-                    //<column-result/>
-                    if (isset($entityElement['name'])) {
-                        $columns[] = [
-                            'name' => (string) $entityElement['name'],
-                        ];
-                    }
-                }
-
-                $metadata->addSqlResultSetMapping(
-                    [
-                        'name'          => (string) $rsmElement['name'],
-                        'entities'      => $entities,
-                        'columns'       => $columns,
-                    ]
-                );
-            }
-        }
-
         if (isset($xmlRoot['inheritance-type'])) {
             $inheritanceType = (string) $xmlRoot['inheritance-type'];
             $metadata->setInheritanceType(constant('Doctrine\ORM\Mapping\ClassMetadata::INHERITANCE_TYPE_' . $inheritanceType));
@@ -203,6 +137,7 @@ class XmlDriver extends FileDriver
                     ];
 
                     if (isset($discrColumn['options'])) {
+                        assert($discrColumn['options'] instanceof SimpleXMLElement);
                         $columnDef['options'] = $this->parseOptions($discrColumn['options']->children());
                     }
 
@@ -214,6 +149,7 @@ class XmlDriver extends FileDriver
                 // Evaluate <discriminator-map...>
                 if (isset($xmlRoot->{'discriminator-map'})) {
                     $map = [];
+                    assert($xmlRoot->{'discriminator-map'}->{'discriminator-mapping'} instanceof SimpleXMLElement);
                     foreach ($xmlRoot->{'discriminator-map'}->{'discriminator-mapping'} as $discrMapElement) {
                         $map[(string) $discrMapElement['value']] = (string) $discrMapElement['class'];
                     }
@@ -252,7 +188,7 @@ class XmlDriver extends FileDriver
                 ) {
                     throw MappingException::invalidIndexConfiguration(
                         $className,
-                        (string) ($indexXml['name'] ?? count($metadata->table['indexes']))
+                        (string) ($indexXml['name'] ?? count($metadata->table['indexes'])),
                     );
                 }
 
@@ -295,7 +231,7 @@ class XmlDriver extends FileDriver
                 ) {
                     throw MappingException::invalidUniqueConstraintConfiguration(
                         $className,
-                        (string) ($uniqueXml['name'] ?? count($metadata->table['uniqueConstraints']))
+                        (string) ($uniqueXml['name'] ?? count($metadata->table['uniqueConstraints'])),
                     );
                 }
 
@@ -317,7 +253,6 @@ class XmlDriver extends FileDriver
 
         // The mapping assignment is done in 2 times as a bug might occurs on some php/xml lib versions
         // The internal SimpleXmlIterator get resetted, to this generate a duplicate field exception
-        $mappings = [];
         // Evaluate <field ...> mappings
         if (isset($xmlRoot->field)) {
             foreach ($xmlRoot->field as $fieldMapping) {
@@ -352,14 +287,6 @@ class XmlDriver extends FileDriver
             }
         }
 
-        foreach ($mappings as $mapping) {
-            if (isset($mapping['version'])) {
-                $metadata->setVersionMapping($mapping);
-            }
-
-            $metadata->mapField($mapping);
-        }
-
         // Evaluate <id ...> mappings
         $associationIds = [];
         foreach ($xmlRoot->id ?? [] as $idElement) {
@@ -388,14 +315,14 @@ class XmlDriver extends FileDriver
                         'sequenceName' => (string) $seqGenerator['sequence-name'],
                         'allocationSize' => (string) $seqGenerator['allocation-size'],
                         'initialValue' => (string) $seqGenerator['initial-value'],
-                    ]
+                    ],
                 );
             } elseif (isset($idElement->{'custom-id-generator'})) {
                 $customGenerator = $idElement->{'custom-id-generator'};
                 $metadata->setCustomGeneratorDefinition(
                     [
                         'class' => (string) $customGenerator['class'],
-                    ]
+                    ],
                 );
             }
         }
@@ -483,10 +410,10 @@ class XmlDriver extends FileDriver
                 if (isset($oneToManyElement->{'order-by'})) {
                     $orderBy = [];
                     foreach ($oneToManyElement->{'order-by'}->{'order-by-field'} ?? [] as $orderByField) {
-                        /** @psalm-suppress DeprecatedConstant */
                         $orderBy[(string) $orderByField['name']] = isset($orderByField['direction'])
                             ? (string) $orderByField['direction']
-                            : (class_exists(Order::class) ? (Order::Ascending)->value : Criteria::ASC);
+                            // @phpstan-ignore classConstant.deprecated
+                            : (enum_exists(Order::class) ? Order::Ascending->value : Criteria::ASC);
                     }
 
                     $mapping['orderBy'] = $orderBy;
@@ -612,10 +539,10 @@ class XmlDriver extends FileDriver
                 if (isset($manyToManyElement->{'order-by'})) {
                     $orderBy = [];
                     foreach ($manyToManyElement->{'order-by'}->{'order-by-field'} ?? [] as $orderByField) {
-                        /** @psalm-suppress DeprecatedConstant */
                         $orderBy[(string) $orderByField['name']] = isset($orderByField['direction'])
                             ? (string) $orderByField['direction']
-                            : (class_exists(Order::class) ? (Order::Ascending)->value : Criteria::ASC);
+                            // @phpstan-ignore classConstant.deprecated
+                            : (enum_exists(Order::class) ? Order::Ascending->value : Criteria::ASC);
                     }
 
                     $mapping['orderBy'] = $orderBy;
@@ -739,9 +666,9 @@ class XmlDriver extends FileDriver
      * Parses (nested) option elements.
      *
      * @return mixed[] The options array.
-     * @psalm-return array<int|string, array<int|string, mixed|string>|bool|string>
+     * @phpstan-return array<int|string, array<int|string, mixed|string>|bool|string>
      */
-    private function parseOptions(?SimpleXMLElement $options): array
+    private function parseOptions(SimpleXMLElement|null $options): array
     {
         $array = [];
 
@@ -774,7 +701,7 @@ class XmlDriver extends FileDriver
      * @param SimpleXMLElement $joinColumnElement The XML element.
      *
      * @return mixed[] The mapping array.
-     * @psalm-return array{
+     * @phpstan-return array{
      *                   name: string,
      *                   referencedColumnName: string,
      *                   unique?: bool,
@@ -818,7 +745,7 @@ class XmlDriver extends FileDriver
       * Parses the given field as array.
       *
       * @return mixed[]
-      * @psalm-return array{
+      * @phpstan-return array{
       *                   fieldName: string,
       *                   type?: string,
       *                   columnName?: string,
@@ -904,7 +831,7 @@ class XmlDriver extends FileDriver
      * Parse / Normalize the cache configuration
      *
      * @return mixed[]
-     * @psalm-return array{usage: int|null, region?: string}
+     * @phpstan-return array{usage: int|null, region?: string}
      */
     private function cacheToArray(SimpleXMLElement $cacheMapping): array
     {
@@ -931,7 +858,7 @@ class XmlDriver extends FileDriver
      * @param SimpleXMLElement $cascadeElement The cascade element.
      *
      * @return string[] The list of cascade options.
-     * @psalm-return list<string>
+     * @phpstan-return list<string>
      */
     private function getCascadeMappings(SimpleXMLElement $cascadeElement): array
     {
@@ -942,7 +869,7 @@ class XmlDriver extends FileDriver
         foreach ($children as $action) {
             // According to the JPA specifications, XML uses "cascade-persist"
             // instead of "persist". Here, both variations
-            // are supported because YAML, Annotation and Attribute use "persist"
+            // are supported because Attribute uses "persist"
             // and we want to make sure that this driver doesn't need to know
             // anything about the supported cascading actions
             $cascades[] = str_replace('cascade-', '', $action->getName());
@@ -951,10 +878,8 @@ class XmlDriver extends FileDriver
         return $cascades;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    protected function loadMappingFile($file)
+    /** @return array<class-string, SimpleXMLElement> */
+    private function doLoadMappingFile(string $file): array
     {
         $this->validateMapping($file);
         $result = [];
@@ -964,19 +889,19 @@ class XmlDriver extends FileDriver
 
         if (isset($xmlElement->entity)) {
             foreach ($xmlElement->entity as $entityElement) {
-                /** @psalm-var class-string $entityName */
+                /** @var class-string $entityName */
                 $entityName          = (string) $entityElement['name'];
                 $result[$entityName] = $entityElement;
             }
         } elseif (isset($xmlElement->{'mapped-superclass'})) {
             foreach ($xmlElement->{'mapped-superclass'} as $mappedSuperClass) {
-                /** @psalm-var class-string $className */
+                /** @var class-string $className */
                 $className          = (string) $mappedSuperClass['name'];
                 $result[$className] = $mappedSuperClass;
             }
         } elseif (isset($xmlElement->embeddable)) {
             foreach ($xmlElement->embeddable as $embeddableElement) {
-                /** @psalm-var class-string $embeddableName */
+                /** @var class-string $embeddableName */
                 $embeddableName          = (string) $embeddableElement['name'];
                 $result[$embeddableName] = $embeddableElement;
             }
@@ -1006,12 +931,7 @@ class XmlDriver extends FileDriver
         }
     }
 
-    /**
-     * @param mixed $element
-     *
-     * @return bool
-     */
-    protected function evaluateBoolean($element)
+    protected function evaluateBoolean(mixed $element): bool
     {
         $flag = (string) $element;
 
