@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\Mapping as ORM;
 use Doctrine\ORM\Query\QueryException;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -128,26 +129,17 @@ class EagerFetchCollectionTest extends OrmFunctionalTestCase
     }
 }
 
-/**
- * @ORM\Entity
- */
+#[ORM\Entity]
 class EagerFetchOwner
 {
-    /**
-     * @ORM\Column(type="integer")
-     * @ORM\Id
-     * @ORM\GeneratedValue()
-     *
-     * @var int
-     */
+    /** @var int */
+    #[ORM\Column(type: 'integer')]
+    #[ORM\Id]
+    #[ORM\GeneratedValue]
     public $id;
 
-    /**
-     * @ORM\OneToMany(targetEntity="EagerFetchChild", mappedBy="owner", fetch="EAGER")
-     *
-     * @var ArrayCollection
-     */
-    public $children;
+    #[ORM\OneToMany(mappedBy: 'owner', targetEntity: EagerFetchChild::class, fetch: 'EAGER')]
+    public Collection $children;
 
     public function __construct()
     {
@@ -155,24 +147,16 @@ class EagerFetchOwner
     }
 }
 
-/**
- * @ORM\Entity
- */
+#[ORM\Entity]
 class EagerFetchChild
 {
-    /**
-     * @ORM\Column(type="integer")
-     * @ORM\Id
-     * @ORM\GeneratedValue()
-     *
-     * @var int
-     */
+    /** @var int */
+    #[ORM\Column(type: 'integer')]
+    #[ORM\Id]
+    #[ORM\GeneratedValue]
     public $id;
 
-    /**
-     * @ORM\ManyToOne(targetEntity="EagerFetchOwner", inversedBy="children")
-     *
-     * @var EagerFetchOwner
-     */
+    /** @var EagerFetchOwner */
+    #[ORM\ManyToOne(targetEntity: EagerFetchOwner::class, inversedBy: 'children')]
     public $owner;
 }
