@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\UnitOfWork;
 use Doctrine\Tests\Models\DDC117\DDC117ApproveChanges;
 use Doctrine\Tests\Models\DDC117\DDC117Article;
@@ -15,30 +14,23 @@ use Doctrine\Tests\Models\DDC117\DDC117Reference;
 use Doctrine\Tests\Models\DDC117\DDC117Translation;
 use Doctrine\Tests\OrmFunctionalTestCase;
 use Exception;
+use PHPUnit\Framework\Attributes\Group;
 
 use function assert;
 use function count;
-use function get_class;
 
-/** @group DDC-117 */
+#[Group('DDC-117')]
 class DDC117Test extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
+    private DDC117Article|null $article1;
 
-    /** @var DDC117Article */
-    private $article1;
+    private DDC117Article|null $article2;
 
-    /** @var DDC117Article */
-    private $article2;
+    private DDC117Reference $reference;
 
-    /** @var DDC117Reference */
-    private $reference;
+    private DDC117Translation|null $translation;
 
-    /** @var DDC117Translation */
-    private $translation;
-
-    /** @var DDC117ArticleDetails */
-    private $articleDetails;
+    private DDC117ArticleDetails $articleDetails;
 
     protected function setUp(): void
     {
@@ -69,7 +61,7 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->clear();
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testAssociationOnlyCompositeKey(): void
     {
         $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
@@ -106,7 +98,7 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->contains($dqlRef);
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testUpdateAssociationEntity(): void
     {
         $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
@@ -122,7 +114,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertEquals('New Description!!', $mapRef->getDescription());
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testFetchDql(): void
     {
         $dql  = 'SELECT r, s FROM Doctrine\Tests\Models\DDC117\DDC117Reference r JOIN r.source s WHERE s.title = ?1';
@@ -136,7 +128,7 @@ class DDC117Test extends OrmFunctionalTestCase
         }
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testRemoveCompositeElement(): void
     {
         $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
@@ -150,10 +142,8 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertNull($this->_em->find(DDC117Reference::class, $idCriteria));
     }
 
-    /**
-     * @group DDC-117
-     * @group non-cacheable
-     */
+    #[Group('DDC-117')]
+    #[Group('non-cacheable')]
     public function testDqlRemoveCompositeElement(): void
     {
         $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
@@ -167,7 +157,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertNull($this->_em->find(DDC117Reference::class, $idCriteria));
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testInverseSideAccess(): void
     {
         $this->article1 = $this->_em->find(DDC117Article::class, $this->article1->id());
@@ -194,7 +184,7 @@ class DDC117Test extends OrmFunctionalTestCase
         }
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testMixedCompositeKey(): void
     {
         $idCriteria = ['article' => $this->article1->id(), 'language' => 'en'];
@@ -215,7 +205,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertInstanceOf(DDC117Translation::class, $this->translation);
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testMixedCompositeKeyViolateUniqueness(): void
     {
         $this->article1 = $this->_em->find(DDC117Article::class, $this->article1->id());
@@ -227,7 +217,7 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->flush();
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testOneToOneForeignObjectId(): void
     {
         $this->article1 = new DDC117Article('Foo');
@@ -242,22 +232,22 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $article = $this->_em->find(get_class($this->article1), $this->article1->id());
+        $article = $this->_em->find($this->article1::class, $this->article1->id());
         assert($article instanceof DDC117Article);
         self::assertEquals('not so very long text!', $article->getText());
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testOneToOneCascadeRemove(): void
     {
-        $article = $this->_em->find(get_class($this->article1), $this->article1->id());
+        $article = $this->_em->find($this->article1::class, $this->article1->id());
         $this->_em->remove($article);
         $this->_em->flush();
 
         self::assertFalse($this->_em->contains($article->getDetails()));
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testOneToOneCascadePersist(): void
     {
         $this->article1       = new DDC117Article('Foo');
@@ -269,7 +259,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertSame($this->articleDetails, $this->_em->find(DDC117ArticleDetails::class, $this->article1));
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testReferencesToForeignKeyEntities(): void
     {
         $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
@@ -290,10 +280,10 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertInstanceOf(DDC117Translation::class, $approveChanges->getTranslation());
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testLoadOneToManyCollectionOfForeignKeyEntities(): void
     {
-        $article = $this->_em->find(get_class($this->article1), $this->article1->id());
+        $article = $this->_em->find($this->article1::class, $this->article1->id());
         assert($article instanceof DDC117Article);
 
         $translations = $article->getTranslations();
@@ -302,7 +292,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertTrue($translations->isInitialized());
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testLoadManyToManyCollectionOfForeignKeyEntities(): void
     {
         $editor = $this->loadEditorFixture();
@@ -319,7 +309,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertContainsOnly(DDC117Translation::class, $editor->reviewingTranslations);
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testClearManyToManyCollectionOfForeignKeyEntities(): void
     {
         $editor = $this->loadEditorFixture();
@@ -329,11 +319,11 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $editor = $this->_em->find(get_class($editor), $editor->id);
+        $editor = $this->_em->find($editor::class, $editor->id);
         self::assertCount(0, $editor->reviewingTranslations);
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testLoadInverseManyToManyCollection(): void
     {
         $editor = $this->loadEditorFixture();
@@ -358,7 +348,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertCount(1, $trans->reviewedByEditors);
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testLoadOneToManyOfSourceEntityWithAssociationIdentifier(): void
     {
         $editor = $this->loadEditorFixture();
@@ -367,7 +357,7 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $editor           = $this->_em->find(get_class($editor), $editor->id);
+        $editor           = $this->_em->find($editor::class, $editor->id);
         $lastTranslatedBy = $editor->reviewingTranslations[0]->getLastTranslatedBy();
         $lastTranslatedBy->count();
 
@@ -378,13 +368,13 @@ class DDC117Test extends OrmFunctionalTestCase
     {
         $editor = new DDC117Editor('beberlei');
 
-        $article1 = $this->_em->find(get_class($this->article1), $this->article1->id());
+        $article1 = $this->_em->find($this->article1::class, $this->article1->id());
         assert($article1 instanceof DDC117Article);
         foreach ($article1->getTranslations() as $translation) {
             $editor->reviewingTranslations[] = $translation;
         }
 
-        $article2 = $this->_em->find(get_class($this->article2), $this->article2->id());
+        $article2 = $this->_em->find($this->article2::class, $this->article2->id());
         assert($article2 instanceof DDC117Article);
         $article2->addTranslation('de', 'Vanille-Krapferl'); // omnomnom
         $article2->addTranslation('fr', "Sorry can't speak french!");
@@ -398,24 +388,10 @@ class DDC117Test extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        return $this->_em->find(get_class($editor), $editor->id);
+        return $this->_em->find($editor::class, $editor->id);
     }
 
-    /** @group DDC-1519 */
-    public function testMergeForeignKeyIdentifierEntity(): void
-    {
-        $idCriteria = ['source' => $this->article1->id(), 'target' => $this->article2->id()];
-
-        $refRep = $this->_em->find(DDC117Reference::class, $idCriteria);
-
-        $this->_em->clear(DDC117Reference::class);
-        $refRep = $this->_em->merge($refRep);
-
-        self::assertEquals($this->article1->id(), $refRep->source()->id());
-        self::assertEquals($this->article2->id(), $refRep->target()->id());
-    }
-
-    /** @group DDC-1652 */
+    #[Group('DDC-1652')]
     public function testArrayHydrationWithCompositeKey(): void
     {
         $dql    = 'SELECT r,s,t FROM Doctrine\Tests\Models\DDC117\DDC117Reference r INNER JOIN r.source s INNER JOIN r.target t';
@@ -441,7 +417,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertCount($before + 3, $data);
     }
 
-    /** @group DDC-2246 */
+    #[Group('DDC-2246')]
     public function testGetEntityState(): void
     {
         if ($this->isSecondLevelCacheEnabled) {
@@ -461,7 +437,7 @@ class DDC117Test extends OrmFunctionalTestCase
         self::assertEquals(UnitOfWork::STATE_MANAGED, $this->_em->getUnitOfWork()->getEntityState($reference));
     }
 
-    /** @group DDC-117 */
+    #[Group('DDC-117')]
     public function testIndexByOnCompositeKeyField(): void
     {
         $article = $this->_em->find(DDC117Article::class, $this->article1->id());
