@@ -16,11 +16,12 @@ use Doctrine\ORM\Mapping\ManyToOne;
 use Doctrine\ORM\Mapping\OneToMany;
 use Doctrine\ORM\Mapping\OrderBy;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use PHPUnit\Framework\Attributes\Group;
 
 use function assert;
 use function class_exists;
 
-/** @group GH7836 */
+#[Group('GH7836')]
 class GH7836Test extends OrmFunctionalTestCase
 {
     protected function setUp(): void
@@ -63,8 +64,8 @@ class GH7836Test extends OrmFunctionalTestCase
             Criteria::create()->orderBy(
                 class_exists(Order::class)
                     ? ['position' => Order::Descending, 'name' => Order::Ascending]
-                    : ['position' => 'DESC', 'name' => 'ASC']
-            )
+                    : ['position' => 'DESC', 'name' => 'ASC'],
+            ),
         );
 
         self::assertSame(200, $children[0]->position);
@@ -84,8 +85,8 @@ class GH7836Test extends OrmFunctionalTestCase
             Criteria::create()->orderBy(
                 class_exists(Order::class)
                     ? ['name' => Order::Ascending, 'position' => Order::Ascending]
-                    : ['name' => 'ASC', 'position' => 'ASC']
-            )
+                    : ['name' => 'ASC', 'position' => 'ASC'],
+            ),
         );
 
         self::assertSame(100, $children[0]->position);
@@ -97,22 +98,17 @@ class GH7836Test extends OrmFunctionalTestCase
     }
 }
 
-/** @Entity */
+#[Entity]
 class GH7836ParentEntity
 {
-    /**
-     * @var int
-     * @Id
-     * @Column(type="integer")
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column(type: 'integer')]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @var Collection<int, GH7836ChildEntity>&Selectable<int, GH7836ChildEntity>
-     * @OneToMany(targetEntity=GH7836ChildEntity::class, mappedBy="parent", fetch="EXTRA_LAZY", cascade={"persist"})
-     * @OrderBy({"position" = "ASC", "name" = "ASC"})
-     */
+    /** @var Collection<int, GH7836ChildEntity>&Selectable<int, GH7836ChildEntity> */
+    #[OneToMany(targetEntity: GH7836ChildEntity::class, mappedBy: 'parent', fetch: 'EXTRA_LAZY', cascade: ['persist'])]
+    #[OrderBy(['position' => 'ASC', 'name' => 'ASC'])]
     private $children;
 
     public function addChild(int $position, string $name): void
@@ -127,39 +123,21 @@ class GH7836ParentEntity
     }
 }
 
-/** @Entity */
+#[Entity]
 class GH7836ChildEntity
 {
-    /**
-     * @var int
-     * @Id
-     * @Column(type="integer")
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column(type: 'integer')]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @var int
-     * @Column(type="integer")
-     */
-    public $position;
-
-    /**
-     * @var string
-     * @Column(type="string", length=255)
-     */
-    public $name;
-
-    /**
-     * @var GH7836ParentEntity
-     * @ManyToOne(targetEntity=GH7836ParentEntity::class, inversedBy="children")
-     */
-    private $parent;
-
-    public function __construct(GH7836ParentEntity $parent, int $position, string $name)
-    {
-        $this->parent   = $parent;
-        $this->position = $position;
-        $this->name     = $name;
+    public function __construct(
+        #[ManyToOne(targetEntity: GH7836ParentEntity::class, inversedBy: 'children')]
+        private GH7836ParentEntity $parent,
+        #[Column(type: 'integer')]
+        public int $position,
+        #[Column(type: 'string', length: 255)]
+        public string $name,
+    ) {
     }
 }
