@@ -4,9 +4,12 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Hydration;
 
+use Doctrine\DBAL\Connection;
+use Doctrine\ORM\Internal\Hydration\HydrationException;
 use Doctrine\ORM\Internal\Hydration\ObjectHydrator;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\PersistentCollection;
+use Doctrine\ORM\Proxy\InternalProxy;
 use Doctrine\ORM\Proxy\ProxyFactory;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\Tests\Mocks\ArrayResultFactory;
@@ -25,15 +28,16 @@ use Doctrine\Tests\Models\Forum\ForumBoard;
 use Doctrine\Tests\Models\Forum\ForumCategory;
 use Doctrine\Tests\Models\Hydration\EntityWithArrayDefaultArrayValueM2M;
 use Doctrine\Tests\Models\Hydration\SimpleEntity;
-use Doctrine\Tests\PHPUnitCompatibility\MockBuilderCompatibilityTools;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\TestCase;
 
 use function count;
 use function property_exists;
+use function sys_get_temp_dir;
 
 class ObjectHydratorTest extends HydrationTestCase
 {
-    use MockBuilderCompatibilityTools;
-
     /** @phpstan-return list<array{mixed}> */
     public static function provideDataForUserEntityResult(): array
     {
@@ -86,7 +90,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -125,7 +129,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -174,7 +178,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -228,7 +232,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -289,7 +293,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -350,7 +354,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -386,9 +390,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *   FROM User u
      *   JOIN u.phonenumbers p
      *  GROUP BY u.id
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testMixedQueryNormalJoin($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -412,7 +415,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -435,9 +438,8 @@ class ObjectHydratorTest extends HydrationTestCase
      * SELECT u, p, UPPER(u.name) nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
      *   JOIN u.phonenumbers p
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testMixedQueryFetchJoin($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -446,7 +448,7 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsPhonenumber::class,
             'p',
             'u',
-            'phonenumbers'
+            'phonenumbers',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -476,7 +478,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -513,9 +515,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *        INDEX BY u.id
      *   JOIN u.phonenumbers p
      *        INDEX BY p.phonenumber
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testMixedQueryFetchJoinCustomIndex($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -524,7 +525,7 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsPhonenumber::class,
             'p',
             'u',
-            'phonenumbers'
+            'phonenumbers',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -556,7 +557,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -591,9 +592,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *   FROM User u
      *   JOIN u.phonenumbers p
      *   JOIN u.articles a
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testMixedQueryMultipleFetchJoin($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -602,13 +602,13 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsPhonenumber::class,
             'p',
             'u',
-            'phonenumbers'
+            'phonenumbers',
         );
         $rsm->addJoinedEntityResult(
             CmsArticle::class,
             'a',
             'u',
-            'articles'
+            'articles',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -670,7 +670,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -701,9 +701,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *   JOIN u.phonenumbers p
      *   JOIN u.articles a
      *   LEFT JOIN a.comments c
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testMixedQueryMultipleDeepMixedFetchJoin($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -712,19 +711,19 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsPhonenumber::class,
             'p',
             'u',
-            'phonenumbers'
+            'phonenumbers',
         );
         $rsm->addJoinedEntityResult(
             CmsArticle::class,
             'a',
             'u',
-            'articles'
+            'articles',
         );
         $rsm->addJoinedEntityResult(
             CmsComment::class,
             'c',
             'a',
-            'comments'
+            'comments',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -800,7 +799,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -869,7 +868,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ForumBoard::class,
             'b',
             'c',
-            'boards'
+            'boards',
         );
         $rsm->addFieldResult('c', 'c__id', 'id');
         $rsm->addFieldResult('c', 'c__position', 'position');
@@ -913,7 +912,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -937,9 +936,8 @@ class ObjectHydratorTest extends HydrationTestCase
     /**
      * SELECT u
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @group DDC-644
      */
+    #[Group('DDC-644')]
     public function testSkipUnknownColumns(): void
     {
         $rsm = new ResultSetMapping();
@@ -956,7 +954,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -967,9 +965,8 @@ class ObjectHydratorTest extends HydrationTestCase
     /**
      * SELECT u.id, u.name
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
     public function testScalarQueryWithoutResultVariables($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -989,7 +986,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1026,25 +1023,29 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $proxyInstance = new ECommerceShipping();
+        // extending the proxy factory to spy on getProxy()
+        $proxyFactory = new class (
+            $this->entityManager,
+            sys_get_temp_dir(),
+            'Proxies',
+            ProxyFactory::AUTOGENERATE_ALWAYS,
+        ) extends ProxyFactory {
+            public function getProxy(string $className, array $identifier): InternalProxy
+            {
+                TestCase::assertSame(ECommerceShipping::class, $className);
+                TestCase::assertSame(['id' => 42], $identifier);
 
-        // mocking the proxy factory
-        $proxyFactory = $this->getMockBuilderWithOnlyMethods(ProxyFactory::class, ['getProxy'])
-                             ->disableOriginalConstructor()
-                             ->getMock();
-
-        $proxyFactory->expects(self::once())
-                     ->method('getProxy')
-                     ->with(self::equalTo(ECommerceShipping::class), ['id' => 42])
-                     ->willReturn($proxyInstance);
+                return parent::getProxy($className, $identifier);
+            }
+        };
 
         $this->entityManager->setProxyFactory($proxyFactory);
 
         // configuring lazy loading
-        $metadata                                           = $this->entityManager->getClassMetadata(ECommerceProduct::class);
-        $metadata->associationMappings['shipping']['fetch'] = ClassMetadata::FETCH_LAZY;
+        $metadata                                         = $this->entityManager->getClassMetadata(ECommerceProduct::class);
+        $metadata->associationMappings['shipping']->fetch = ClassMetadata::FETCH_LAZY;
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1076,23 +1077,29 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $proxyInstance = new ECommerceShipping();
 
-        // mocking the proxy factory
-        $proxyFactory = $this->getMockBuilderWithOnlyMethods(ProxyFactory::class, ['getProxy'])
-                             ->disableOriginalConstructor()
-                             ->getMock();
+        // extending the proxy factory to spy on getProxy()
+        $proxyFactory = new class (
+            $this->entityManager,
+            sys_get_temp_dir(),
+            'Proxies',
+            ProxyFactory::AUTOGENERATE_ALWAYS,
+        ) extends ProxyFactory {
+            public function getProxy(string $className, array $identifier): InternalProxy
+            {
+                TestCase::assertSame(ECommerceShipping::class, $className);
+                TestCase::assertSame(['id' => 42], $identifier);
 
-        $proxyFactory->expects(self::once())
-                     ->method('getProxy')
-                     ->with(self::equalTo(ECommerceShipping::class), ['id' => 42])
-                     ->willReturn($proxyInstance);
+                return parent::getProxy($className, $identifier);
+            }
+        };
 
         $this->entityManager->setProxyFactory($proxyFactory);
 
         // configuring lazy loading
-        $metadata                                           = $this->entityManager->getClassMetadata(ECommerceProduct::class);
-        $metadata->associationMappings['shipping']['fetch'] = ClassMetadata::FETCH_LAZY;
+        $metadata                                         = $this->entityManager->getClassMetadata(ECommerceProduct::class);
+        $metadata->associationMappings['shipping']->fetch = ClassMetadata::FETCH_LAZY;
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1116,13 +1123,13 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsArticle::class,
             'a',
             'u',
-            'articles'
+            'articles',
         );
         $rsm->addJoinedEntityResult(
             CmsComment::class,
             'c',
             'a',
-            'comments'
+            'comments',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -1152,7 +1159,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1179,13 +1186,13 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsArticle::class,
             'a',
             'u',
-            'articles'
+            'articles',
         );
         $rsm->addJoinedEntityResult(
             CmsComment::class,
             'c',
             'a',
-            'comments'
+            'comments',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -1215,7 +1222,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1256,22 +1263,21 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $hydrator = new ObjectHydrator($this->entityManager);
 
-        $iterableResult = $hydrator->iterate(
-            ArrayResultFactory::createFromArray($resultSet),
-            $rsm
+        $iterableResult = $hydrator->toIterable(
+            $this->createResultMock($resultSet),
+            $rsm,
         );
         $rowNum         = 0;
 
-        while (($row = $iterableResult->next()) !== false) {
-            self::assertEquals(1, count($row));
-            self::assertInstanceOf(CmsUser::class, $row[0]);
+        foreach ($iterableResult as $row) {
+            self::assertInstanceOf(CmsUser::class, $row);
 
             if ($rowNum === 0) {
-                self::assertEquals(1, $row[0]->id);
-                self::assertEquals('romanb', $row[0]->name);
+                self::assertEquals(1, $row->id);
+                self::assertEquals('romanb', $row->name);
             } elseif ($rowNum === 1) {
-                self::assertEquals(2, $row[0]->id);
-                self::assertEquals('jwage', $row[0]->name);
+                self::assertEquals(2, $row->id);
+                self::assertEquals('jwage', $row->name);
             }
 
             ++$rowNum;
@@ -1280,8 +1286,8 @@ class ObjectHydratorTest extends HydrationTestCase
         self::assertSame(2, $rowNum);
 
         $iterableResult = $hydrator->toIterable(
-            ArrayResultFactory::createFromArray($resultSet),
-            $rsm
+            $this->createResultMock($resultSet),
+            $rsm,
         );
         $rowNum         = 0;
 
@@ -1329,23 +1335,22 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $hydrator       = new ObjectHydrator($this->entityManager);
         $rowNum         = 0;
-        $iterableResult = $hydrator->iterate(
-            ArrayResultFactory::createFromArray($resultSet),
-            $rsm
+        $iterableResult = $hydrator->toIterable(
+            ArrayResultFactory::createWrapperResultFromArray($resultSet, $this->createMock(Connection::class)),
+            $rsm,
         );
 
-        while (($row = $iterableResult->next()) !== false) {
-            self::assertEquals(1, count($row));
-            self::assertArrayHasKey(0, $row);
-            self::assertArrayHasKey('user', $row[0]);
-            self::assertInstanceOf(CmsUser::class, $row[0]['user']);
+        foreach ($iterableResult as $row) {
+            self::assertCount(1, $row);
+            self::assertArrayHasKey('user', $row);
+            self::assertInstanceOf(CmsUser::class, $row['user']);
 
             if ($rowNum === 0) {
-                self::assertEquals(1, $row[0]['user']->id);
-                self::assertEquals('romanb', $row[0]['user']->name);
+                self::assertEquals(1, $row['user']->id);
+                self::assertEquals('romanb', $row['user']->name);
             } elseif ($rowNum === 1) {
-                self::assertEquals(2, $row[0]['user']->id);
-                self::assertEquals('jwage', $row[0]['user']->name);
+                self::assertEquals(2, $row['user']->id);
+                self::assertEquals('jwage', $row['user']->name);
             }
 
             ++$rowNum;
@@ -1355,8 +1360,8 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $rowNum         = 0;
         $iterableResult = $hydrator->toIterable(
-            ArrayResultFactory::createFromArray($resultSet),
-            $rsm
+            $this->createResultMock($resultSet),
+            $rsm,
         );
 
         foreach ($iterableResult as $row) {
@@ -1385,9 +1390,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *
      * SELECT u, g, p
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @group DDC-809
      */
+    #[Group('DDC-809')]
     public function testManyToManyHydration(): void
     {
         $rsm = new ResultSetMapping();
@@ -1488,7 +1492,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1508,9 +1512,8 @@ class ObjectHydratorTest extends HydrationTestCase
      *
      * SELECT u As user, g, p
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @group DDC-809
      */
+    #[Group('DDC-809')]
     public function testManyToManyHydrationWithAliasedUserEntity(): void
     {
         $rsm = new ResultSetMapping();
@@ -1611,7 +1614,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1632,10 +1635,9 @@ class ObjectHydratorTest extends HydrationTestCase
     /**
      * SELECT u, UPPER(u.name) as nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @group DDC-1358
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
+    #[Group('DDC-1358')]
     public function testMissingIdForRootEntity($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -1669,7 +1671,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1691,10 +1693,9 @@ class ObjectHydratorTest extends HydrationTestCase
      * SELECT u, p, UPPER(u.name) AS nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
      *   LEFT JOIN u.phonenumbers u
-     *
-     * @group DDC-1358
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
+    #[Group('DDC-1358')]
     public function testMissingIdForCollectionValuedChildEntity($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -1703,7 +1704,7 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsPhonenumber::class,
             'p',
             'u',
-            'phonenumbers'
+            'phonenumbers',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -1739,7 +1740,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1753,10 +1754,9 @@ class ObjectHydratorTest extends HydrationTestCase
      * SELECT u, a, UPPER(u.name) AS nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
      *   JOIN u.address a
-     *
-     * @group DDC-1358
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
+    #[Group('DDC-1358')]
     public function testMissingIdForSingleValuedChildEntity($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -1765,7 +1765,7 @@ class ObjectHydratorTest extends HydrationTestCase
             CmsAddress::class,
             'a',
             'u',
-            'address'
+            'address',
         );
         $rsm->addFieldResult('u', 'u__id', 'id');
         $rsm->addFieldResult('u', 'u__status', 'status');
@@ -1793,7 +1793,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1807,10 +1807,9 @@ class ObjectHydratorTest extends HydrationTestCase
      * SELECT u, UPPER(u.name) AS nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
      *        INDEX BY u.id
-     *
-     * @group DDC-1385
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
+    #[Group('DDC-1385')]
     public function testIndexByAndMixedResult($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -1835,7 +1834,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1851,10 +1850,9 @@ class ObjectHydratorTest extends HydrationTestCase
     /**
      * SELECT UPPER(u.name) AS nameUpper
      *   FROM Doctrine\Tests\Models\CMS\CmsUser u
-     *
-     * @group DDC-1385
-     * @dataProvider provideDataForUserEntityResult
      */
+    #[DataProvider('provideDataForUserEntityResult')]
+    #[Group('DDC-1385')]
     public function testIndexByScalarsOnly($userEntityKey): void
     {
         $rsm = new ResultSetMapping();
@@ -1869,7 +1867,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ['sclr0' => 'JWAGE'],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
@@ -1878,14 +1876,14 @@ class ObjectHydratorTest extends HydrationTestCase
                 'ROMANB' => ['nameUpper' => 'ROMANB'],
                 'JWAGE'  => ['nameUpper' => 'JWAGE'],
             ],
-            $result
+            $result,
         );
     }
 
-    /** @group DDC-1470 */
+    #[Group('DDC-1470')]
     public function testMissingMetaMappingException(): void
     {
-        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectException(HydrationException::class);
         $this->expectExceptionMessage('The meta mapping for the discriminator column "c_discr" is missing for "Doctrine\Tests\Models\Company\CompanyFixContract" using the DQL alias "c".');
         $rsm = new ResultSetMapping();
 
@@ -1901,15 +1899,15 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $hydrator->hydrateAll($stmt, $rsm);
     }
 
-    /** @group DDC-1470 */
+    #[Group('DDC-1470')]
     public function testMissingDiscriminatorColumnException(): void
     {
-        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectException(HydrationException::class);
         $this->expectExceptionMessage('The discriminator column "discr" is missing for "Doctrine\Tests\Models\Company\CompanyEmployee" using the DQL alias "e".');
         $rsm = new ResultSetMapping();
 
@@ -1932,15 +1930,15 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $hydrator->hydrateAll($stmt, $rsm);
     }
 
-    /** @group DDC-3076 */
+    #[Group('DDC-3076')]
     public function testInvalidDiscriminatorValueException(): void
     {
-        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectException(HydrationException::class);
         $this->expectExceptionMessage('The discriminator value "subworker" is invalid. It must be one of "person", "manager", "employee".');
         $rsm = new ResultSetMapping();
 
@@ -1958,7 +1956,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $hydrator->hydrateAll($stmt, $rsm);
     }
@@ -1979,7 +1977,7 @@ class ObjectHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = ArrayResultFactory::createFromArray($resultSet);
+        $stmt     = $this->createResultMock($resultSet);
         $hydrator = new ObjectHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
