@@ -8,6 +8,7 @@ use Doctrine\ORM\Mapping\Builder\ClassMetadataBuilder;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmTestCase;
+use stdClass;
 
 class FieldBuilderTest extends OrmTestCase
 {
@@ -18,11 +19,11 @@ class FieldBuilderTest extends OrmTestCase
         $fieldBuilder = $cmBuilder->createField('aField', 'string');
 
         $fieldBuilder->generatedValue('CUSTOM');
-        $fieldBuilder->setCustomIdGenerator('stdClass');
+        $fieldBuilder->setCustomIdGenerator(stdClass::class);
 
         $fieldBuilder->build();
 
         self::assertEquals(ClassMetadata::GENERATOR_TYPE_CUSTOM, $cmBuilder->getClassMetadata()->generatorType);
-        self::assertEquals(['class' => 'stdClass'], $cmBuilder->getClassMetadata()->customGeneratorDefinition);
+        self::assertEquals(['class' => stdClass::class], $cmBuilder->getClassMetadata()->customGeneratorDefinition);
     }
 }
