@@ -4,10 +4,11 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM;
 
+use BadMethodCallException;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Criteria;
 use Doctrine\Common\Collections\Order;
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Cache;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\Query\Expr\Join;
@@ -21,10 +22,10 @@ use Doctrine\Tests\Models\CMS\CmsGroup;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmTestCase;
 use InvalidArgumentException;
+use PHPUnit\Framework\Attributes\Group;
 
 use function array_filter;
 use function class_exists;
-use function get_class;
 
 /**
  * Test case for the QueryBuilder class used to build DQL query string in a
@@ -32,10 +33,7 @@ use function get_class;
  */
 class QueryBuilderTest extends OrmTestCase
 {
-    use VerifyDeprecations;
-
-    /** @var EntityManagerMock */
-    private $entityManager;
+    private EntityManagerMock $entityManager;
 
     protected function setUp(): void
     {
@@ -56,16 +54,7 @@ class QueryBuilderTest extends OrmTestCase
             ->delete(CmsUser::class, 'u')
             ->select('u.id', 'u.username');
 
-        self::assertEquals($qb->getType(), QueryBuilder::SELECT);
-    }
-
-    public function testEmptySelectSetsType(): void
-    {
-        $qb = $this->entityManager->createQueryBuilder()
-            ->delete(CmsUser::class, 'u')
-            ->select();
-
-        self::assertEquals($qb->getType(), QueryBuilder::SELECT);
+        $this->assertValidQueryBuilder($qb, 'SELECT u.id, u.username FROM Doctrine\Tests\Models\CMS\CmsUser u');
     }
 
     public function testDeleteSetsType(): void
@@ -74,7 +63,7 @@ class QueryBuilderTest extends OrmTestCase
             ->from(CmsUser::class, 'u')
             ->delete();
 
-        self::assertEquals($qb->getType(), QueryBuilder::DELETE);
+        $this->assertValidQueryBuilder($qb, 'DELETE Doctrine\Tests\Models\CMS\CmsUser u');
     }
 
     public function testUpdateSetsType(): void
@@ -83,7 +72,7 @@ class QueryBuilderTest extends OrmTestCase
             ->from(CmsUser::class, 'u')
             ->update();
 
-        self::assertEquals($qb->getType(), QueryBuilder::UPDATE);
+        $this->assertValidQueryBuilder($qb, 'UPDATE Doctrine\Tests\Models\CMS\CmsUser u');
     }
 
     public function testSimpleSelect(): void
@@ -95,6 +84,15 @@ class QueryBuilderTest extends OrmTestCase
         $this->assertValidQueryBuilder($qb, 'SELECT u.id, u.username FROM Doctrine\Tests\Models\CMS\CmsUser u');
     }
 
+    public function testSimpleSelectArray(): void
+    {
+        $qb = $this->entityManager->createQueryBuilder()
+            ->from(CmsUser::class, 'u')
+            ->select(['u.id', 'u.username']);
+
+        $this->assertValidQueryBuilder($qb, 'SELECT u.id, u.username FROM Doctrine\Tests\Models\CMS\CmsUser u');
+    }
+
     public function testSimpleDelete(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -150,7 +148,7 @@ class QueryBuilderTest extends OrmTestCase
 
         $this->assertValidQueryBuilder(
             $qb,
-            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id'
+            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id',
         );
     }
 
@@ -164,7 +162,7 @@ class QueryBuilderTest extends OrmTestCase
 
         $this->assertValidQueryBuilder(
             $qb,
-            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id'
+            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id',
         );
     }
 
@@ -176,12 +174,12 @@ class QueryBuilderTest extends OrmTestCase
             ->from(CmsUser::class, 'u')
             ->innerJoin('u.articles', 'a', Join::ON, $qb->expr()->andX(
                 $qb->expr()->eq('u.id', 'a.author_id'),
-                $qb->expr()->isNotNull('u.name')
+                $qb->expr()->isNotNull('u.name'),
             ));
 
         $this->assertValidQueryBuilder(
             $qb,
-            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id AND u.name IS NOT NULL'
+            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a ON u.id = a.author_id AND u.name IS NOT NULL',
         );
     }
 
@@ -193,12 +191,12 @@ class QueryBuilderTest extends OrmTestCase
             ->from(CmsUser::class, 'u')
             ->innerJoin('u.articles', 'a', Join::WITH, $qb->expr()->in(
                 'u.id',
-                [1, 2, 3]
+                [1, 2, 3],
             ));
 
         $this->assertValidQueryBuilder(
             $qb,
-            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a WITH u.id IN(1, 2, 3)'
+            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a WITH u.id IN(1, 2, 3)',
         );
     }
 
@@ -211,7 +209,7 @@ class QueryBuilderTest extends OrmTestCase
 
         $this->assertValidQueryBuilder(
             $qb,
-            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a INDEX BY a.name ON u.id = a.author_id'
+            'SELECT u, a FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.articles a INDEX BY a.name ON u.id = a.author_id',
         );
     }
 
@@ -290,6 +288,18 @@ class QueryBuilderTest extends OrmTestCase
         $this->assertValidQueryBuilder($qb, 'SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.id = :uid');
     }
 
+    public function testWhereWithUnexpectedNamedArguments(): void
+    {
+        $qb = $this->entityManager->createQueryBuilder()
+            ->select('u')
+            ->from(CmsUser::class, 'u');
+
+        $this->expectException(BadMethodCallException::class);
+        $this->expectExceptionMessage('Invalid call to Doctrine\ORM\QueryBuilder::where(), unknown named arguments: foo, bar');
+
+        $qb->where(foo: 'u.id = :uid', bar: 'u.name = :name');
+    }
+
     public function testComplexAndWhere(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -493,7 +503,7 @@ class QueryBuilderTest extends OrmTestCase
         $criteria = new Criteria();
         $criteria->where($criteria->expr()->andX(
             $criteria->expr()->eq('field', 'value1'),
-            $criteria->expr()->eq('field', 'value2')
+            $criteria->expr()->eq('field', 'value2'),
         ));
 
         $qb->addCriteria($criteria);
@@ -503,7 +513,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertNotNull($qb->getParameter('field_1'));
     }
 
-    /** @group DDC-2844 */
+    #[Group('DDC-2844')]
     public function testAddCriteriaWhereWithMultipleParametersWithSameField(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -520,7 +530,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value2', $qb->getParameter('field_1')->getValue());
     }
 
-    /** @group DDC-2844 */
+    #[Group('DDC-2844')]
     public function testAddCriteriaWhereWithMultipleParametersWithDifferentFields(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -537,7 +547,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value2', $qb->getParameter('field2')->getValue());
     }
 
-    /** @group DDC-2844 */
+    #[Group('DDC-2844')]
     public function testAddCriteriaWhereWithMultipleParametersWithSubpathsAndDifferentProperties(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -554,7 +564,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value2', $qb->getParameter('field2')->getValue());
     }
 
-    /** @group DDC-2844 */
+    #[Group('DDC-2844')]
     public function testAddCriteriaWhereWithMultipleParametersWithSubpathsAndSameProperty(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -586,7 +596,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals('u.field DESC', (string) $orderBy[0]);
     }
 
-    /** @group DDC-3108 */
+    #[Group('DDC-3108')]
     public function testAddCriteriaOrderOnJoinAlias(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -642,7 +652,7 @@ class QueryBuilderTest extends OrmTestCase
             ->from(CmsUser::class, 'u');
         $q  = $qb->getQuery();
 
-        self::assertEquals(Query::class, get_class($q));
+        self::assertEquals(Query::class, $q::class);
     }
 
     public function testSetParameter(): void
@@ -839,21 +849,6 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals($this->entityManager, $qb->getEntityManager());
     }
 
-    public function testInitialStateIsClean(): void
-    {
-        $qb = $this->entityManager->createQueryBuilder();
-        self::assertEquals(QueryBuilder::STATE_CLEAN, $qb->getState());
-    }
-
-    public function testAlteringQueryChangesStateToDirty(): void
-    {
-        $qb = $this->entityManager->createQueryBuilder()
-            ->select('u')
-            ->from(CmsUser::class, 'u');
-
-        self::assertEquals(QueryBuilder::STATE_DIRTY, $qb->getState());
-    }
-
     public function testSelectWithFuncExpression(): void
     {
         $qb   = $this->entityManager->createQueryBuilder();
@@ -907,7 +902,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertCount(0, $qb->getDQLPart('orderBy'));
     }
 
-    /** @group DDC-867 */
+    #[Group('DDC-867')]
     public function testDeepClone(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -925,7 +920,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals(2, $expr->count(), 'Modifying the second query should affect the first one.');
     }
 
-    /** @group DDC-3108 */
+    #[Group('DDC-3108')]
     public function testAddCriteriaWhereWithJoinAlias(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -943,7 +938,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value2', $qb->getParameter('alias2_field')->getValue());
     }
 
-    /** @group DDC-3108 */
+    #[Group('DDC-3108')]
     public function testAddCriteriaWhereWithDefaultAndJoinAlias(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -961,7 +956,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value2', $qb->getParameter('alias2_field')->getValue());
     }
 
-    /** @group DDC-3108 */
+    #[Group('DDC-3108')]
     public function testAddCriteriaWhereOnJoinAliasWithDuplicateFields(): void
     {
         $qb = $this->entityManager->createQueryBuilder();
@@ -981,7 +976,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('value3', $qb->getParameter('alias2_field_2')->getValue());
     }
 
-    /** @group DDC-1933 */
+    #[Group('DDC-1933')]
     public function testParametersAreCloned(): void
     {
         $originalQb = new QueryBuilder($this->entityManager);
@@ -1044,7 +1039,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u INNER JOIN u.groups g', $qb->getDQL());
     }
 
-    /** @group DDC-1211 */
+    #[Group('DDC-1211')]
     public function testEmptyStringLiteral(): void
     {
         $expr = $this->entityManager->getExpressionBuilder();
@@ -1056,7 +1051,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals("SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.username = ''", $qb->getDQL());
     }
 
-    /** @group DDC-1211 */
+    #[Group('DDC-1211')]
     public function testEmptyNumericLiteral(): void
     {
         $expr = $this->entityManager->getExpressionBuilder();
@@ -1068,7 +1063,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.username = 0', $qb->getDQL());
     }
 
-    /** @group DDC-1227 */
+    #[Group('DDC-1227')]
     public function testAddFromString(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -1078,7 +1073,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u', $qb->getDQL());
     }
 
-    /** @group DDC-1619 */
+    #[Group('DDC-1619')]
     public function testAddDistinct(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -1101,7 +1096,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals('SELECT DISTINCT u FROM Doctrine\Tests\Models\CMS\CmsUser u', $qb->getDQL());
     }
 
-    /** @group DDC-2192 */
+    #[Group('DDC-2192')]
     public function testWhereAppend(): void
     {
         $this->expectException(InvalidArgumentException::class);
@@ -1151,7 +1146,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals(Cache::MODE_REFRESH, $query->getCacheMode());
     }
 
-    /** @group DDC-2253 */
+    #[Group('DDC-2253')]
     public function testRebuildsFromParts(): void
     {
         $qb = $this->entityManager->createQueryBuilder()
@@ -1194,7 +1189,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertEquals(['u', 'g'], $aliases);
     }
 
-    /** @group 6699 */
+    #[Group('6699')]
     public function testGetParameterTypeJuggling(): void
     {
         $builder = $this->entityManager->createQueryBuilder()
@@ -1209,7 +1204,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame(0, $builder->getParameter('0')->getValue());
     }
 
-    /** @group 6699 */
+    #[Group('6699')]
     public function testSetParameterWithNameZeroIsNotOverridden(): void
     {
         $builder = $this->entityManager->createQueryBuilder()
@@ -1226,7 +1221,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('Doctrine', $builder->getParameter('name')->getValue());
     }
 
-    /** @group 6699 */
+    #[Group('6699')]
     public function testSetParameterWithNameZeroDoesNotOverrideAnotherParameter(): void
     {
         $builder = $this->entityManager->createQueryBuilder()
@@ -1243,7 +1238,7 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('Doctrine', $builder->getParameter('name')->getValue());
     }
 
-    /** @group 6699 */
+    #[Group('6699')]
     public function testSetParameterWithTypeJugglingWorks(): void
     {
         $builder = $this->entityManager->createQueryBuilder()
@@ -1274,24 +1269,61 @@ class QueryBuilderTest extends OrmTestCase
         self::assertSame('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u LEFT JOIN Doctrine\Tests\Models\CMS\CmsArticle a0 INNER JOIN Doctrine\Tests\Models\CMS\CmsArticle a1', $builder->getDQL());
     }
 
-    public function testUpdateDeprecationMessage(): void
+    public function testUpdateWithoutAlias(): void
     {
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/9733');
+        $qb = $this->entityManager->createQueryBuilder();
 
-        $qb = $this->entityManager->createQueryBuilder()
-            ->update(CmsUser::class . ' u')
-            ->set('u.username', ':username');
-
-        $this->assertValidQueryBuilder($qb, 'UPDATE Doctrine\Tests\Models\CMS\CmsUser u  SET u.username = :username');
+        $this->expectException(InvalidArgumentException::class);
+        $this->expectExceptionMessage('Doctrine\ORM\QueryBuilder::update(): The alias for entity Doctrine\Tests\Models\CMS\CmsUser u must not be omitted.');
+        $qb->update(CmsUser::class . ' u');
     }
 
-    public function testDeleteDeprecationMessage(): void
+    public function testDeleteWithoutAlias(): void
     {
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/9733');
+        $qb = $this->entityManager->createQueryBuilder();
 
-        $qb = $this->entityManager->createQueryBuilder()
-            ->delete(CmsUser::class . ' u');
+        $this->expectException(InvalidArgumentException::class);
+        $this->expectExceptionMessage('Doctrine\ORM\QueryBuilder::delete(): The alias for entity Doctrine\Tests\Models\CMS\CmsUser u must not be omitted.');
+        $qb->delete(CmsUser::class . ' u');
+    }
 
-        $this->assertValidQueryBuilder($qb, 'DELETE Doctrine\Tests\Models\CMS\CmsUser u ');
+    public function testCreateNamedParameter(): void
+    {
+        $qb = $this->entityManager->createQueryBuilder();
+
+        $qb->select('u')
+            ->from(CmsUser::class, 'u')
+            ->where(
+                $qb->expr()->eq('u.name', $qb->createNamedParameter('john doe', Types::STRING)),
+            )
+            ->orWhere(
+                $qb->expr()->eq('u.rank', $qb->createNamedParameter(100, Types::INTEGER)),
+            );
+
+        self::assertEquals('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.name = :dcValue1 OR u.rank = :dcValue2', $qb->getDQL());
+        self::assertEquals('john doe', $qb->getParameter('dcValue1')->getValue());
+        self::assertEquals(Types::STRING, $qb->getParameter('dcValue1')->getType());
+        self::assertEquals(100, $qb->getParameter('dcValue2')->getValue());
+        self::assertEquals(Types::INTEGER, $qb->getParameter('dcValue2')->getType());
+    }
+
+    public function testCreateNamedParameterCustomPlaceholder(): void
+    {
+        $qb = $this->entityManager->createQueryBuilder();
+
+        $qb->select('u')
+            ->from(CmsUser::class, 'u')
+            ->where(
+                $qb->expr()->eq('u.name', $qb->createNamedParameter('john doe', Types::STRING, ':test')),
+            )
+            ->andWhere(
+                $qb->expr()->eq('u.rank', $qb->createNamedParameter(100, Types::INTEGER)),
+            );
+
+        self::assertEquals('SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.name = :test AND u.rank = :dcValue1', $qb->getDQL());
+        self::assertEquals('john doe', $qb->getParameter('test')->getValue());
+        self::assertEquals(Types::STRING, $qb->getParameter('test')->getType());
+        self::assertEquals(100, $qb->getParameter('dcValue1')->getValue());
+        self::assertEquals(Types::INTEGER, $qb->getParameter('dcValue1')->getType());
     }
 }
