@@ -6,36 +6,43 @@ namespace Doctrine\Tests\ORM\Tools\Pagination;
 
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Driver;
+use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Result;
 use Doctrine\ORM\Decorator\EntityManagerDecorator;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Internal\Hydration\AbstractHydrator;
 use Doctrine\ORM\Query;
+use Doctrine\ORM\Query\QueryException;
 use Doctrine\ORM\Tools\Pagination\Paginator;
-use Doctrine\Tests\Mocks\ConnectionMock;
 use Doctrine\Tests\OrmTestCase;
-use Doctrine\Tests\PHPUnitCompatibility\MockBuilderCompatibilityTools;
 use PHPUnit\Framework\MockObject\MockObject;
 
 class PaginatorTest extends OrmTestCase
 {
-    use MockBuilderCompatibilityTools;
-
-    /** @var Connection&MockObject */
-    private $connection;
-    /** @var EntityManagerInterface&MockObject */
-    private $em;
-    /** @var AbstractHydrator&MockObject */
-    private $hydrator;
+    private Connection&MockObject $connection;
+    private EntityManagerInterface&MockObject $em;
+    private AbstractHydrator&MockObject $hydrator;
 
     protected function setUp(): void
     {
-        $this->connection = $this->getMockBuilderWithOnlyMethods(ConnectionMock::class, ['executeQuery'])
-            ->setConstructorArgs([[], $this->createMock(Driver::class)])
+        $platform = $this->getMockBuilder(AbstractPlatform::class)
+            ->onlyMethods(['supportsIdentityColumns'])
+            ->getMockForAbstractClass();
+        $platform->method('supportsIdentityColumns')
+            ->willReturn(true);
+
+        $driver = $this->createMock(Driver::class);
+        $driver->method('getDatabasePlatform')
+            ->willReturn($platform);
+
+        $this->connection = $this->getMockBuilder(Connection::class)
+            ->onlyMethods(['executeQuery'])
+            ->setConstructorArgs([[], $driver])
             ->getMock();
 
-        $this->em = $this->getMockBuilderWithOnlyMethods(EntityManagerDecorator::class, ['newHydrator'])
-            ->setConstructorArgs([$this->getTestEntityManager($this->connection)])
+        $this->em = $this->getMockBuilder(EntityManagerDecorator::class)
+            ->onlyMethods(['newHydrator'])
+            ->setConstructorArgs([$this->createTestEntityManagerWithConnection($this->connection)])
             ->getMock();
 
         $this->hydrator = $this->createMock(AbstractHydrator::class);
@@ -59,7 +66,7 @@ class PaginatorTest extends OrmTestCase
                     WHERE a.user = u AND 1 = :paramInSubSelect
                 ) AS HIDDEN max_version
             FROM Doctrine\\Tests\\Models\\CMS\\CmsUser u
-            WHERE u.id = :paramInWhere'
+            WHERE u.id = :paramInWhere',
         );
         $query->setParameters(['paramInWhere' => $paramInWhere, 'paramInSubSelect' => $paramInSubSelect]);
         $query->setMaxResults(1);
@@ -99,7 +106,7 @@ class PaginatorTest extends OrmTestCase
     {
         $result = $this->getMockBuilder(Result::class)->disableOriginalConstructor()->getMock();
         $this->connection->expects(self::exactly(1))->method('executeQuery')->willReturn($result);
-        $this->expectException(Query\QueryException::class);
+        $this->expectException(QueryException::class);
         $this->expectExceptionMessage('Too many parameters: the query defines 1 parameters and you bound 2');
 
         $this->createPaginatorWithExtraParametersWithoutOutputWalkers([[10]])->getIterator();
