@@ -14,6 +14,7 @@ use Doctrine\ORM\Mapping\Entity;
 use Doctrine\ORM\Mapping\GeneratedValue;
 use Doctrine\ORM\Mapping\Id;
 use Doctrine\ORM\Mapping\InheritanceType;
+use Doctrine\ORM\Mapping\InverseJoinColumn;
 use Doctrine\ORM\Mapping\JoinColumn;
 use Doctrine\ORM\Mapping\JoinTable;
 use Doctrine\ORM\Mapping\ManyToMany;
@@ -27,14 +28,14 @@ use Doctrine\ORM\Tools\SchemaValidator;
 use Doctrine\Tests\Models\BigIntegers\BigIntegers;
 use Doctrine\Tests\Models\ECommerce\ECommerceCart;
 use Doctrine\Tests\OrmTestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 
 class SchemaValidatorTest extends OrmTestCase
 {
-    /** @var EntityManagerInterface */
-    private $em = null;
+    private EntityManagerInterface|null $em = null;
 
-    /** @var SchemaValidator */
-    private $validator = null;
+    private SchemaValidator|null $validator = null;
 
     protected function setUp(): void
     {
@@ -42,7 +43,7 @@ class SchemaValidatorTest extends OrmTestCase
         $this->validator = new SchemaValidator($this->em);
     }
 
-    /** @dataProvider modelSetProvider */
+    #[DataProvider('modelSetProvider')]
     public function testCmsModelSet(string $path): void
     {
         $this->em->getConfiguration()
@@ -64,7 +65,7 @@ class SchemaValidatorTest extends OrmTestCase
         ];
     }
 
-    /** @group DDC-1439 */
+    #[Group('DDC-1439')]
     public function testInvalidManyToManyJoinColumnSchema(): void
     {
         $class1 = $this->em->getClassMetadata(InvalidEntity1::class);
@@ -77,11 +78,11 @@ class SchemaValidatorTest extends OrmTestCase
                 "The inverse join columns of the many-to-many table 'Entity1Entity2' have to contain to ALL identifier columns of the target entity 'Doctrine\Tests\ORM\Tools\InvalidEntity2', however 'key4' are missing.",
                 "The join columns of the many-to-many table 'Entity1Entity2' have to contain to ALL identifier columns of the source entity 'Doctrine\Tests\ORM\Tools\InvalidEntity1', however 'key2' are missing.",
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-1439 */
+    #[Group('DDC-1439')]
     public function testInvalidToOneJoinColumnSchema(): void
     {
         $class1 = $this->em->getClassMetadata(InvalidEntity1::class);
@@ -94,11 +95,11 @@ class SchemaValidatorTest extends OrmTestCase
                 "The referenced column name 'id' has to be a primary key column on the target entity class 'Doctrine\Tests\ORM\Tools\InvalidEntity1'.",
                 "The join columns of the association 'assoc' have to match to ALL identifier columns of the target entity 'Doctrine\Tests\ORM\Tools\InvalidEntity1', however 'key1, key2' are missing.",
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-1587 */
+    #[Group('DDC-1587')]
     public function testValidOneToOneAsIdentifierSchema(): void
     {
         $class1 = $this->em->getClassMetadata(DDC1587ValidEntity2::class);
@@ -109,7 +110,7 @@ class SchemaValidatorTest extends OrmTestCase
         self::assertEquals([], $ce);
     }
 
-    /** @group DDC-1649 */
+    #[Group('DDC-1649')]
     public function testInvalidTripleAssociationAsKeyMapping(): void
     {
         $classThree = $this->em->getClassMetadata(DDC1649Three::class);
@@ -120,11 +121,11 @@ class SchemaValidatorTest extends OrmTestCase
                 "Cannot map association 'Doctrine\Tests\ORM\Tools\DDC1649Three#two as identifier, because the target entity 'Doctrine\Tests\ORM\Tools\DDC1649Two' also maps an association as identifier.",
                 "The referenced column name 'id' has to be a primary key column on the target entity class 'Doctrine\Tests\ORM\Tools\DDC1649Two'.",
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-3274 */
+    #[Group('DDC-3274')]
     public function testInvalidBiDirectionalRelationMappingMissingInversedByAttribute(): void
     {
         $class = $this->em->getClassMetadata(DDC3274One::class);
@@ -136,11 +137,11 @@ class SchemaValidatorTest extends OrmTestCase
                 'relationship, but the specified mappedBy association on the target-entity ' .
                 "Doctrine\Tests\ORM\Tools\DDC3274Two#one does not contain the required 'inversedBy=\"two\"' attribute.",
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group 9536 */
+    #[Group('9536')]
     public function testInvalidBiDirectionalRelationMappingMissingMappedByAttribute(): void
     {
         $class = $this->em->getClassMetadata(Issue9536Owner::class);
@@ -153,11 +154,11 @@ class SchemaValidatorTest extends OrmTestCase
                 "Doctrine\Tests\ORM\Tools\Issue9536Target#two does not contain the required 'mappedBy=\"one\"' " .
                 'attribute.',
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-3322 */
+    #[Group('DDC-3322')]
     public function testInvalidOrderByInvalidField(): void
     {
         $class = $this->em->getClassMetadata(DDC3322One::class);
@@ -168,11 +169,11 @@ class SchemaValidatorTest extends OrmTestCase
                 'The association Doctrine\Tests\ORM\Tools\DDC3322One#invalidAssoc is ordered by a foreign field ' .
                 'invalidField that is not a field on the target entity Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1.',
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-3322 */
+    #[Group('DDC-3322')]
     public function testInvalidOrderByCollectionValuedAssociation(): void
     {
         $class = $this->em->getClassMetadata(DDC3322Two::class);
@@ -183,11 +184,11 @@ class SchemaValidatorTest extends OrmTestCase
                 'The association Doctrine\Tests\ORM\Tools\DDC3322Two#invalidAssoc is ordered by a field oneToMany ' .
                 'on Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1 that is a collection-valued association.',
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group DDC-3322 */
+    #[Group('DDC-3322')]
     public function testInvalidOrderByAssociationInverseSide(): void
     {
         $class = $this->em->getClassMetadata(DDC3322Three::class);
@@ -198,23 +199,10 @@ class SchemaValidatorTest extends OrmTestCase
                 'The association Doctrine\Tests\ORM\Tools\DDC3322Three#invalidAssoc is ordered by a field oneToOneInverse ' .
                 'on Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1 that is the inverse side of an association.',
             ],
-            $ce
+            $ce,
         );
     }
 
-    /** @group 8052 */
-    public function testInvalidAssociationInsideEmbeddable(): void
-    {
-        $class = $this->em->getClassMetadata(EmbeddableWithAssociation::class);
-        $ce    = $this->validator->validateClass($class);
-
-        self::assertEquals(
-            ["Embeddable 'Doctrine\Tests\ORM\Tools\EmbeddableWithAssociation' does not support associations"],
-            $ce
-        );
-    }
-
-    /** @group 8771 */
     public function testMappedSuperclassNotPresentInDiscriminator(): void
     {
         $class1 = $this->em->getClassMetadata(MappedSuperclassEntity::class);
@@ -238,476 +226,335 @@ class SchemaValidatorTest extends OrmTestCase
 
         self::assertEquals(
             ["The target entity 'Doctrine\Tests\ORM\Tools\InvalidMappedSuperClass' specified on Doctrine\Tests\ORM\Tools\InvalidMappedSuperClass#selfWhatever is a mapped superclass. This is not possible since there is no table that a foreign key could refer to."],
-            $ce
+            $ce,
         );
     }
 
-    /**
-     * @requires PHP 7.4
-     */
     public function testBigIntProperty(): void
     {
         $class = $this->em->getClassMetadata(BigIntegers::class);
 
         self::assertSame(
             ['The field \'Doctrine\Tests\Models\BigIntegers\BigIntegers#three\' has the property type \'float\' that differs from the metadata field type \'int|string\' returned by the \'bigint\' DBAL type.'],
-            $this->validator->validateClass($class)
+            $this->validator->validateClass($class),
         );
     }
 }
 
-/** @MappedSuperclass */
+#[MappedSuperclass]
 abstract class MappedSuperclassEntity extends ParentEntity
 {
 }
 
-/**
- * @Entity
- * @InheritanceType("SINGLE_TABLE")
- * @DiscriminatorMap({"child" = ChildEntity::class})
- */
+#[Entity]
+#[InheritanceType('SINGLE_TABLE')]
+#[DiscriminatorMap(['child' => ChildEntity::class])]
 abstract class ParentEntity
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key;
 }
 
-/** @Entity */
+#[Entity]
 class ChildEntity extends MappedSuperclassEntity
 {
 }
 
-/** @Entity */
+#[Entity]
 class InvalidEntity1
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key1;
 
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key2;
 
-    /**
-     * @var ArrayCollection
-     * @ManyToMany (targetEntity="InvalidEntity2")
-     * @JoinTable (name="Entity1Entity2",
-     *      joinColumns={@JoinColumn(name="key1", referencedColumnName="key1")},
-     *      inverseJoinColumns={@JoinColumn(name="key3", referencedColumnName="key3")}
-     * )
-     */
+    /** @var ArrayCollection */
+    #[JoinTable(name: 'Entity1Entity2')]
+    #[JoinColumn(name: 'key1', referencedColumnName: 'key1')]
+    #[InverseJoinColumn(name: 'key3', referencedColumnName: 'key3')]
+    #[ManyToMany(targetEntity: 'InvalidEntity2')]
     protected $entity2;
 }
 
-/** @Entity */
+#[Entity]
 class InvalidEntity2
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key3;
 
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key4;
 
-    /**
-     * @var InvalidEntity1
-     * @ManyToOne(targetEntity="InvalidEntity1")
-     */
+    /** @var InvalidEntity1 */
+    #[ManyToOne(targetEntity: 'InvalidEntity1')]
     protected $assoc;
 }
 
-/**
- * @Entity(repositoryClass="Entity\Repository\Agent")
- * @Table(name="agent")
- */
+#[Table(name: 'agent')]
+#[Entity(repositoryClass: 'Entity\Repository\Agent')]
 class DDC1587ValidEntity1
 {
-    /**
-     * @var int
-     * @Id
-     * @GeneratedValue
-     * @Column(name="pk", type="integer")
-     */
-    private $pk;
+    #[Id]
+    #[GeneratedValue]
+    #[Column(name: 'pk', type: 'integer')]
+    private int $pk;
 
-    /**
-     * @var string
-     * @Column(name="name", type="string", length=32)
-     */
-    private $name;
+    #[Column(name: 'name', type: 'string', length: 32)]
+    private string $name;
 
-    /**
-     * @var Identifier
-     * @OneToOne(targetEntity="DDC1587ValidEntity2", cascade={"all"}, mappedBy="agent")
-     */
+    /** @var Identifier */
+    #[OneToOne(targetEntity: 'DDC1587ValidEntity2', cascade: ['all'], mappedBy: 'agent')]
     private $identifier;
 }
 
-/**
- * @Entity
- * @Table
- */
+#[Table]
+#[Entity]
 class DDC1587ValidEntity2
 {
-    /**
-     * @var DDC1587ValidEntity1
-     * @Id
-     * @OneToOne(targetEntity="DDC1587ValidEntity1", inversedBy="identifier")
-     * @JoinColumn(name="pk_agent", referencedColumnName="pk", nullable=false)
-     */
-    private $agent;
+    #[Id]
+    #[OneToOne(targetEntity: 'DDC1587ValidEntity1', inversedBy: 'identifier')]
+    #[JoinColumn(name: 'pk_agent', referencedColumnName: 'pk', nullable: false)]
+    private DDC1587ValidEntity1 $agent;
 
-    /**
-     * @var string
-     * @Column(name="num", type="string", length=16, nullable=true)
-     */
-    private $num;
+    #[Column(name: 'num', type: 'string', length: 16, nullable: true)]
+    private string $num;
 }
 
-/** @Entity */
+#[Entity]
 class DDC1649One
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
     public $id;
 }
 
-/** @Entity */
+#[Entity]
 class DDC1649Two
 {
-    /**
-     * @var DDC1649One
-     * @Id
-     * @ManyToOne(targetEntity="DDC1649One")
-     */
+    /** @var DDC1649One */
+    #[Id]
+    #[ManyToOne(targetEntity: 'DDC1649One')]
     public $one;
 }
 
-/** @Entity */
+#[Entity]
 class DDC1649Three
 {
-    /**
-     * @var DDC1649Two
-     * @Id
-     * @ManyToOne(targetEntity="DDC1649Two")
-     * @JoinColumn(name="id", referencedColumnName="id")
-     */
-    private $two;
+    #[Id]
+    #[ManyToOne(targetEntity: 'DDC1649Two')]
+    #[JoinColumn(name: 'id', referencedColumnName: 'id')]
+    private DDC1649Two $two;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3274One
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
     private $id;
 
-    /**
-     * @var ArrayCollection
-     * @OneToMany(targetEntity="DDC3274Two", mappedBy="one")
-     */
-    private $two;
+    #[OneToMany(targetEntity: 'DDC3274Two', mappedBy: 'one')]
+    private ArrayCollection $two;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3274Two
 {
-    /**
-     * @var DDC3274One
-     * @Id
-     * @ManyToOne(targetEntity="DDC3274One")
-     */
-    private $one;
+    #[Id]
+    #[ManyToOne(targetEntity: 'DDC3274One')]
+    private DDC3274One $one;
 }
 
-/** @Entity */
+#[Entity]
 class Issue9536Target
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
     private $id;
 
-    /**
-     * @var Issue9536Owner
-     * @OneToOne(targetEntity="Issue9536Owner")
-     */
-    private $two;
+    #[OneToOne(targetEntity: 'Issue9536Owner')]
+    private Issue9536Owner $two;
 }
 
-/** @Entity */
+#[Entity]
 class Issue9536Owner
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
     private $id;
 
-    /**
-     * @var Issue9536Target
-     * @OneToOne(targetEntity="Issue9536Target", inversedBy="two")
-     */
-    private $one;
+    #[OneToOne(targetEntity: 'Issue9536Target', inversedBy: 'two')]
+    private Issue9536Target $one;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3322ValidEntity1
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
     private $id;
 
-    /**
-     * @var DDC3322One
-     * @ManyToOne(targetEntity="DDC3322One", inversedBy="validAssoc")
-     */
-    private $oneValid;
+    #[ManyToOne(targetEntity: 'DDC3322One', inversedBy: 'validAssoc')]
+    private DDC3322One $oneValid;
 
-    /**
-     * @var DDC3322One
-     * @ManyToOne(targetEntity="DDC3322One", inversedBy="invalidAssoc")
-     */
-    private $oneInvalid;
+    #[ManyToOne(targetEntity: 'DDC3322One', inversedBy: 'invalidAssoc')]
+    private DDC3322One $oneInvalid;
 
-    /**
-     * @var DDC3322Two
-     * @ManyToOne(targetEntity="DDC3322Two", inversedBy="validAssoc")
-     */
-    private $twoValid;
+    #[ManyToOne(targetEntity: 'DDC3322Two', inversedBy: 'validAssoc')]
+    private DDC3322Two $twoValid;
 
-    /**
-     * @var DDC3322Two
-     * @ManyToOne(targetEntity="DDC3322Two", inversedBy="invalidAssoc")
-     */
-    private $twoInvalid;
+    #[ManyToOne(targetEntity: 'DDC3322Two', inversedBy: 'invalidAssoc')]
+    private DDC3322Two $twoInvalid;
 
-    /**
-     * @var DDC3322Three
-     * @ManyToOne(targetEntity="DDC3322Three", inversedBy="validAssoc")
-     */
-    private $threeValid;
+    #[ManyToOne(targetEntity: 'DDC3322Three', inversedBy: 'validAssoc')]
+    private DDC3322Three $threeValid;
 
-    /**
-     * @var DDC3322Three
-     * @ManyToOne(targetEntity="DDC3322Three", inversedBy="invalidAssoc")
-     */
-    private $threeInvalid;
+    #[ManyToOne(targetEntity: 'DDC3322Three', inversedBy: 'invalidAssoc')]
+    private DDC3322Three $threeInvalid;
 
-    /**
-     * @var DDC3322ValidEntity2
-     * @OneToMany(targetEntity="DDC3322ValidEntity2", mappedBy="manyToOne")
-     */
-    private $oneToMany;
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity2', mappedBy: 'manyToOne')]
+    private DDC3322ValidEntity2 $oneToMany;
 
-    /**
-     * @var DDC3322ValidEntity2
-     * @ManyToOne(targetEntity="DDC3322ValidEntity2", inversedBy="oneToMany")
-     */
-    private $manyToOne;
+    #[ManyToOne(targetEntity: 'DDC3322ValidEntity2', inversedBy: 'oneToMany')]
+    private DDC3322ValidEntity2 $manyToOne;
 
-    /**
-     * @var DDC3322ValidEntity2
-     * @OneToOne(targetEntity="DDC3322ValidEntity2", mappedBy="oneToOneOwning")
-     */
-    private $oneToOneInverse;
+    #[OneToOne(targetEntity: 'DDC3322ValidEntity2', mappedBy: 'oneToOneOwning')]
+    private DDC3322ValidEntity2 $oneToOneInverse;
 
-    /**
-     * @var DDC3322ValidEntity2
-     * @OneToOne(targetEntity="DDC3322ValidEntity2", inversedBy="oneToOneInverse")
-     */
-    private $oneToOneOwning;
+    #[OneToOne(targetEntity: 'DDC3322ValidEntity2', inversedBy: 'oneToOneInverse')]
+    private DDC3322ValidEntity2 $oneToOneOwning;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3322ValidEntity2
 {
-    /**
-     * @var int
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @var DDC3322ValidEntity1
-     * @ManyToOne(targetEntity="DDC3322ValidEntity1", inversedBy="oneToMany")
-     */
-    private $manyToOne;
+    #[ManyToOne(targetEntity: 'DDC3322ValidEntity1', inversedBy: 'oneToMany')]
+    private DDC3322ValidEntity1 $manyToOne;
 
-    /**
-     * @var DDC3322ValidEntity1
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="manyToOne")
-     */
-    private $oneToMany;
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'manyToOne')]
+    private DDC3322ValidEntity1 $oneToMany;
 
-    /**
-     * @var DDC3322ValidEntity1
-     * @OneToOne(targetEntity="DDC3322ValidEntity1", inversedBy="oneToOneInverse")
-     */
-    private $oneToOneOwning;
+    #[OneToOne(targetEntity: 'DDC3322ValidEntity1', inversedBy: 'oneToOneInverse')]
+    private DDC3322ValidEntity1 $oneToOneOwning;
 
-    /**
-     * @var DDC3322ValidEntity1
-     * @OneToOne(targetEntity="DDC3322ValidEntity1", mappedBy="oneToOneOwning")
-     */
-    private $oneToOneInverse;
+    #[OneToOne(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'oneToOneOwning')]
+    private DDC3322ValidEntity1 $oneToOneInverse;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3322One
 {
-    /**
-     * @var int
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @phpstan-var Collection<int, DDC3322ValidEntity1>
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="oneValid")
-     * @OrderBy({"id" = "ASC"})
-     */
+    /** @phpstan-var Collection<int, DDC3322ValidEntity1> */
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'oneValid')]
+    #[OrderBy(['id' => 'ASC'])]
     private $validAssoc;
 
-    /**
-     * @phpstan-var Collection<int, DDC3322ValidEntity1>
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="oneInvalid")
-     * @OrderBy({"invalidField" = "ASC"})
-     */
+    /** @phpstan-var Collection<int, DDC3322ValidEntity1> */
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'oneInvalid')]
+    #[OrderBy(['invalidField' => 'ASC'])]
     private $invalidAssoc;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3322Two
 {
-    /**
-     * @var int
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @phpstan-var Collection<int, DDC3322ValidEntity1>
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="twoValid")
-     * @OrderBy({"manyToOne" = "ASC"})
-     */
+    /** @phpstan-var Collection<int, DDC3322ValidEntity1> */
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'twoValid')]
+    #[OrderBy(['manyToOne' => 'ASC'])]
     private $validAssoc;
 
-    /**
-     * @phpstan-var Collection<int, DDC3322ValidEntity1>
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="twoInvalid")
-     * @OrderBy({"oneToMany" = "ASC"})
-     */
+    /** @phpstan-var Collection<int, DDC3322ValidEntity1> */
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'twoInvalid')]
+    #[OrderBy(['oneToMany' => 'ASC'])]
     private $invalidAssoc;
 }
 
-/** @Entity */
+#[Entity]
 class DDC3322Three
 {
-    /**
-     * @var int
-     * @Id
-     * @Column
-     * @GeneratedValue
-     */
-    private $id;
+    #[Id]
+    #[Column]
+    #[GeneratedValue]
+    private int $id;
 
-    /**
-     * @var DDC3322ValidEntity1
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="threeValid")
-     * @OrderBy({"oneToOneOwning" = "ASC"})
-     */
-    private $validAssoc;
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'threeValid')]
+    #[OrderBy(['oneToOneOwning' => 'ASC'])]
+    private DDC3322ValidEntity1 $validAssoc;
 
-    /**
-     * @phpstan-var Collection<int, DDC3322ValidEntity1>
-     * @OneToMany(targetEntity="DDC3322ValidEntity1", mappedBy="threeInvalid")
-     * @OrderBy({"oneToOneInverse" = "ASC"})
-     */
+    /** @phpstan-var Collection<int, DDC3322ValidEntity1> */
+    #[OneToMany(targetEntity: 'DDC3322ValidEntity1', mappedBy: 'threeInvalid')]
+    #[OrderBy(['oneToOneInverse' => 'ASC'])]
     private $invalidAssoc;
 }
 
-/** @Embeddable */
+#[Embeddable]
 class EmbeddableWithAssociation
 {
-    /**
-     * @var ECommerceCart
-     * @OneToOne(targetEntity="Doctrine\Tests\Models\ECommerce\ECommerceCart")
-     */
-    private $cart;
+    #[OneToOne(targetEntity: 'Doctrine\Tests\Models\ECommerce\ECommerceCart')]
+    private ECommerceCart $cart;
 }
 
-/**
- * @Entity
- * @InheritanceType("SINGLE_TABLE")
- * @DiscriminatorMap({"child" = Issue9095Child::class})
- */
+#[Entity]
+#[InheritanceType('SINGLE_TABLE')]
+#[DiscriminatorMap(['child' => Issue9095Child::class])]
 abstract class Issue9095Parent
 {
-    /**
-     * @var mixed
-     * @Id
-     * @Column
-     */
+    /** @var mixed */
+    #[Id]
+    #[Column]
     protected $key;
 }
 
-/** @Entity */
+#[Entity]
 abstract class Issue9095AbstractChild extends Issue9095Parent
 {
 }
 
-/** @Entity */
+#[Entity]
 class Issue9095Child extends Issue9095AbstractChild
 {
 }
 
-/** @MappedSuperclass */
+#[MappedSuperclass]
 class InvalidMappedSuperClass
 {
-    /**
-     * @phpstan-var Collection<int, self>
-     * @ManyToMany(targetEntity="InvalidMappedSuperClass", mappedBy="invalid")
-     */
+    /** @phpstan-var Collection<int, self> */
+    #[ManyToMany(targetEntity: 'InvalidMappedSuperClass', mappedBy: 'invalid')]
     private $selfWhatever;
 }
